#ifndef _EFL_VPATH_FILE_CORE_EO_H_
#define _EFL_VPATH_FILE_CORE_EO_H_

#ifndef _EFL_VPATH_FILE_CORE_EO_CLASS_TYPE
#define _EFL_VPATH_FILE_CORE_EO_CLASS_TYPE

typedef Eo Efl_Vpath_File_Core;

#endif

#ifndef _EFL_VPATH_FILE_CORE_EO_TYPES
#define _EFL_VPATH_FILE_CORE_EO_TYPES


#endif
/** Core EFL implementation of a Vpath File
 *
 * @since 1.18
 *
 * @ingroup Efl_Vpath_File_Core
 */
#define EFL_VPATH_FILE_CORE_CLASS efl_vpath_file_core_class_get()

EWAPI const Efl_Class *efl_vpath_file_core_class_get(void);

#endif
